Structs
- Cairo
Lint Allow - Plugin with
declared_allowsthat does not emit diagnostics. Add it to avoid compiler warnings on unsupportedallowattribute arguments.
declared_allows that does not emit diagnostics.
Add it to avoid compiler warnings on unsupported allow attribute arguments.